import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_i18n/flutter_i18n.dart';

extension StringExtension on String {
  bool isNumber() {
    try {
      double.parse(this);
      return true;
    } on Exception catch (_) {
      return false;
    }
  }

  String i18n(BuildContext context,
      {final String? fallbackKey,
      final Map<String, String>? translationParams}) {
    try {
      String utf8Encoded = FlutterI18n.translate(context, this,
          fallbackKey: fallbackKey, translationParams: translationParams);
      var utf8Runes = utf8Encoded.runes.toList();
      return utf8.decode(utf8Runes);
    } on Exception catch (_) {
      return "";
    }
  }
}
